@@ -31,8 +31,8 @@
 
 from typing import Callable, List
 
-from PyQt5.QtWidgets import QAction, QActionGroup, QWidget
-from PyQt5.QtGui import QKeySequence, QIcon
+from PyQt6.QtWidgets import QWidget
+from PyQt6.QtGui import QKeySequence, QIcon, QAction, QActionGroup
 
 try:
     import matplotlib.figure as matplotlib_figure
@@ -44,6 +44,11 @@ try:
 except ImportError:
     enchant = None
 
+try:
+    import dateutil
+except ImportError:
+    dateutil = None
+
 try:
     from pyspread.icons import Icon
     from pyspread.lib.attrdict import AttrDict
@@ -180,12 +185,13 @@ class MainWindowActions(AttrDict):
                                   self.parent.on_preferences,
                                   icon=Icon.preferences,
                                   statustip='Pyspread setup parameters',
-                                  role=QAction.PreferencesRole)
+                                  role=QAction.MenuRole.PreferencesRole)
 
         self.quit = Action(self.parent, "&Quit", self.parent.closeEvent,
                            icon=Icon.quit,
                            shortcut='Ctrl+Q' if self.shortcuts else "",
-                           statustip='Exit pyspread', role=QAction.QuitRole)
+                           statustip='Exit pyspread',
+                           role=QAction.MenuRole.QuitRole)
 
     def create_edit_actions(self):
         """actions for Edit menu"""
@@ -271,18 +277,11 @@ class MainWindowActions(AttrDict):
 
         self.toggle_selection_mode = Action(
             self.parent, "Selection mode",
-            self.parent.grid.set_selection_mode,
+            self.parent.grid.toggle_selection_mode,
             icon=Icon.selection_mode, checkable=True,
             shortcut='Ins',
             statustip='Enter/leave selection mode')
 
-        self.quote = Action(self.parent, "&Quote",
-                            self.parent.grid.on_quote,
-                            icon=Icon.quote,
-                            shortcut='Ctrl+Return' if self.shortcuts else "",
-                            statustip="Convert cells' code to strings by "
-                                      "addding quotes")
-
         self.insert_rows = Action(self.parent, "Insert rows",
                                   self.parent.grid.on_insert_rows,
                                   icon=Icon.insert_row,
@@ -401,7 +400,7 @@ class MainWindowActions(AttrDict):
             Action(self.parent, "Refresh selected cells",
                    self.parent.grid.refresh_selected_frozen_cells,
                    icon=Icon.refresh,
-                   shortcut=QKeySequence.Refresh if self.shortcuts else "",
+                   shortcut=QKeySequence.StandardKey.Refresh if self.shortcuts else "",
                    statustip='Refresh selected cells even when frozen')
 
         self.toggle_periodic_updates = \
@@ -765,6 +764,37 @@ class MainWindowActions(AttrDict):
                                    statustip='Create and display matplotlib '
                                              'chart')
 
+        self.quote = Action(self.parent, "&Quote",
+                            self.parent.grid.on_quote,
+                            icon=Icon.quote,
+                            shortcut='Ctrl+Return' if self.shortcuts else "",
+                            statustip="Convert cells' code to strings by "
+                                      "addding quotes")
+
+        self.money = Action(self.parent, "&Money",
+                            self.parent.grid.on_money,
+                            icon=Icon.money,
+                            shortcut='Ctrl+M' if self.shortcuts else "",
+                            statustip="Convert cells' code to Money")
+
+        if dateutil is not None:
+            self.datetime = Action(self.parent, "Datetime",
+                                   self.parent.grid.on_datetime,
+                                   icon=Icon.datetime,
+                                   statustip="Convert cells' code to datetime")
+
+            self.date = Action(self.parent, "&Date",
+                               self.parent.grid.on_date,
+                               icon=Icon.date,
+                               shortcut='Ctrl+D' if self.shortcuts else "",
+                               statustip="Convert cells' code to date")
+
+            self.time = Action(self.parent, "&Time",
+                               self.parent.grid.on_time,
+                               icon=Icon.time,
+                               shortcut='Ctrl+T' if self.shortcuts else "",
+                               statustip="Convert cells' code to time")
+
         self.insert_sum = Action(self.parent, "Insert sum",
                                  self.parent.workflows.macro_insert_sum,
                                  icon=Icon.insert_sum,
@@ -795,7 +825,7 @@ class MainWindowActions(AttrDict):
                             self.parent.on_about,
                             icon=Icon.pyspread,
                             statustip='About pyspread',
-                            role=QAction.AboutRole)
+                            role=QAction.MenuRole.AboutRole)
 
     def disable_unavailable(self):
         """Disables unavailable menu items e.g. due to missing dependencies"""
