@@ -40,12 +40,12 @@ except ImportError:
     from pyspread.lib.dataclasses import dataclass  # Python 3.6 compatibility
 from typing import List, Tuple
 
-from PyQt5.QtCore import Qt, QModelIndex, QRectF, QPointF
-from PyQt5.QtGui import (QBrush, QPainter, QPalette, QPen,
+from PyQt6.QtCore import Qt, QModelIndex, QRectF, QPointF
+from PyQt6.QtGui import (QBrush, QPainter, QPalette, QPen,
                          QPainterPath, QPolygonF, QPainterPathStroker)
 
-from PyQt5.QtGui import QColor as __QColor
-from PyQt5.QtWidgets import QTableView, QStyleOptionViewItem
+from PyQt6.QtGui import QColor as __QColor
+from PyQt6.QtWidgets import QTableView, QStyleOptionViewItem
 from functools import lru_cache
 
 
@@ -349,7 +349,7 @@ class CellEdgeRenderer:
                      x, y, width, height)
 
         color = self.borders.color
-        self.painter.setPen(QPen(Qt.NoPen))
+        self.painter.setPen(QPen(Qt.PenStyle.NoPen))
         self.painter.setBrush(QBrush(color))
 
         try:
@@ -364,7 +364,7 @@ class CellEdgeRenderer:
             self.intersection_cache[cache_key] = intersection
 
         self.painter.drawPath(intersection)
-        self.painter.setPen(QPen(Qt.SolidLine))
+        self.painter.setPen(QPen(Qt.PenStyle.SolidLine))
 
 
 class QColorCache(dict):
@@ -376,7 +376,7 @@ class QColorCache(dict):
 
     def __missing__(self, key):
         if key is None:
-            qcolor = QColor(self.grid.palette().color(QPalette.Mid))
+            qcolor = QColor(self.grid.palette().color(QPalette.ColorRole.Mid))
         else:
             qcolor = QColor(*key)
 
@@ -470,13 +470,10 @@ class CellRenderer:
         self.option = option
         self.index = index
 
-        try:
-            self.painter.setRenderHint(QPainter.LosslessImageRendering, True)
-        except AttributeError:
-            # Qt <5.13
-            pass
-
-        self.painter.setRenderHint(QPainter.SmoothPixmapTransform, True)
+        self.painter.setRenderHint(QPainter.RenderHint.LosslessImageRendering,
+                                   True)
+        self.painter.setRenderHint(QPainter.RenderHint.SmoothPixmapTransform,
+                                   True)
 
         self.cell_attributes = grid.model.code_array.cell_attributes
         self.key = index.row(), index.column(), self.grid.table
@@ -538,10 +535,9 @@ class CellRenderer:
 
         """
 
-        zoomed_width = max(1, width * zoom)
-
         return QPen(QColor(255, 255, 255, 0), zoomed_width,
-                    Qt.SolidLine, Qt.FlatCap, Qt.MiterJoin)
+                    Qt.PenStyle.SolidLine, Qt.PenCapStyle.FlatCap,
+                    Qt.PenJoinStyle.MiterJoin)
 
     def _draw_line(self, point1: QPointF, point2: QPointF, width: float,
                    color: QColor, clip_path: QPainterPath):
@@ -562,7 +558,7 @@ class CellRenderer:
         alpha = max(0, round(255 - 255 * width * zoom))
 
         if width * zoom > 1.01:
-            self.painter.setRenderHint(QPainter.Antialiasing, True)
+            self.painter.setRenderHint(QPainter.RenderHint.Antialiasing, True)
 
         screen_painting = self.grid.main_window.print_area is None
 
@@ -587,7 +583,7 @@ class CellRenderer:
             self.painter.setBrush(QBrush(color))
             self.painter.drawPath(clip_path.intersected(stroked_path))
 
-        self.painter.setRenderHint(QPainter.Antialiasing, False)
+        self.painter.setRenderHint(QPainter.RenderHint.Antialiasing, False)
 
     def paint_bottom_border(self, rect: QRectF, clip_path: QPainterPath):
         """Paint bottom border of cell
