@@ -56,7 +56,7 @@ import datetime
 import decimal
 from decimal import Decimal  # Needed
 from importlib import reload
-from inspect import isgenerator
+from inspect import getmembers, isfunction, isgenerator
 import io
 from itertools import product
 import re
@@ -68,13 +68,37 @@ from typing import (
 
 import numpy
 
-from PyQt5.QtGui import QImage, QPixmap  # Needed
+from PyQt6.QtGui import QImage, QPixmap  # Needed
+
+try:
+    import dateutil
+except ImportError:
+    dateutil = None
 
 try:
     from matplotlib.figure import Figure
 except ImportError:
     Figure = None
 
+try:
+    import pycel
+    import pycel.excellib
+    import pycel.lib.date_time
+    import pycel.lib.engineering
+    import pycel.lib.information
+    import pycel.lib.logical
+    import pycel.lib.lookup
+    import pycel.lib.stats
+    import pycel.lib.text
+
+except ImportError:
+    pycel = None
+
+try:
+    from openpyxl.worksheet.cell_range import CellRange
+except ImportError:
+    CellRange = None
+
 try:
     from moneyed import Money
 except ImportError:
@@ -87,6 +111,7 @@ try:
     from pyspread.lib.exception_handling import get_user_codeframe
     from pyspread.lib.typechecks import is_stringlike
     from pyspread.lib.selection import Selection
+    from pyspread.lib.string_helpers import ZEN
 except ImportError:
     from settings import Settings
     from lib.attrdict import AttrDict
@@ -94,6 +119,70 @@ except ImportError:
     from lib.exception_handling import get_user_codeframe
     from lib.typechecks import is_stringlike
     from lib.selection import Selection
+    from lib.string_helpers import ZEN
+
+
+class_format_functions = {}
+
+
+def update_xl_list():
+    """Updates list of pycel modules to be accessible from within cells"""
+
+    if pycel is not None:
+        try:
+            xl_members = getmembers(pycel.excellib)
+            xl_members += getmembers(pycel.lib.date_time)
+            xl_members += getmembers(pycel.lib.engineering)
+            xl_members += getmembers(pycel.lib.information)
+            xl_members += getmembers(pycel.lib.logical)
+            xl_members += getmembers(pycel.lib.lookup)
+            xl_members += getmembers(pycel.lib.stats)
+            xl_members += getmembers(pycel.lib.text)
+
+            for name, fun in xl_members:
+                globals()[name] = fun
+
+        except UnboundLocalError:
+            return  # openpyxl is not installed
+
+
+def _table_from_address(addr: str) -> int:
+    """Convert xlsx sheetname to table
+
+    :param sheetname: Name if Excel sheet as in global sheetnames
+    :return: Table index
+
+    """
+
+    if "!" in addr:
+        sheetname = addr.split("!")[0]
+        return _sheetnames.index(sheetname)
+        # Works because _sheetnames is global
+    return Z  # Works in cells because Z is global
+
+
+def _R_(addr: str) -> Any:
+    """Helper for pycel references in xlsx code
+
+    TODO: Move to separate lib module
+
+    """
+
+    l, t, r, b = CellRange(addr).bounds
+    table = _table_from_address(addr)
+    return S[t-1:b, l-1:r, table]  # Works in cells because S is global
+
+
+def _C_(addr: str) -> Any:
+    """Helper for pycel references in xlsx code
+
+    TODO: Move to separate lib module
+
+    """
+
+    l, t, _, _ = CellRange(addr).bounds
+    table = _table_from_address(addr)
+    return S[t-1, l-1, table]  # Works in cells because S is global
 
 
 class DefaultCellAttributeDict(AttrDict):
@@ -681,7 +770,7 @@ class DataArray:
             if isinstance(key_ele, slice):
                 # We have something slice-like here
 
-                length = key[axis]
+                length = self.shape[axis]
                 slice_range = range(*key_ele.indices(length))
                 single_keys_per_dim.append(slice_range)
 
@@ -1235,7 +1324,10 @@ class CodeArray(DataArray):
         """
 
         # Change numpy array repr function for grid cell results
-        numpy.set_string_function(lambda s: repr(s.tolist()))
+        try:
+            numpy.set_printoptions(formatter = {'all': lambda s: repr(s.tolist() if hasattr(s, "tolist") else s)})
+        except AttributeError:
+            numpy.set_string_function(lambda s: repr(s.tolist() if hasattr(s, "tolist") else s))
 
         # Prevent unchanged cells from being recalculated on cursor movement
 
@@ -1369,6 +1461,16 @@ class CodeArray(DataArray):
 
         """
 
+        # Help helper function that fixes help being displayed in stdout
+        def help(*args) -> str:
+            """Returns help string for object arguments"""
+
+            if not args:
+                return ZEN
+
+            from pydoc import render_doc, plaintext
+            return render_doc(*args, renderer=plaintext)
+
         # Flatten helper function
         def nn(val: numpy.array) -> numpy.array:
             """Returns flat numpy array without None values"""
@@ -1382,7 +1484,7 @@ class CodeArray(DataArray):
                                    dtype="O")
 
         env_dict = {'X': key[0], 'Y': key[1], 'Z': key[2], 'bz2': bz2,
-                    'base64': base64, 'nn': nn, 'Figure': Figure,
+                    'base64': base64, 'nn': nn, 'help': help, 'Figure': Figure,
                     'R': key[0], 'C': key[1], 'T': key[2], 'S': self}
         env = self._get_updated_environment(env_dict=env_dict)
 
@@ -1466,16 +1568,47 @@ class CodeArray(DataArray):
                      'copy', 'imap', 'ifilter', 'Selection', 'DictGrid',
                      'numpy', 'CodeArray', 'DataArray', 'datetime', 'Decimal',
                      'decimal', 'signal', 'Any', 'Dict', 'Iterable', 'List',
-                     'NamedTuple', 'Sequence', 'Tuple', 'Union']
+                     'NamedTuple', 'Sequence', 'Tuple', 'Union', '_R_', '_C_',
+                     '_table_from_address', 'CellRange',
+                     'class_format_functions']
 
         try:
             from moneyed import Money
+            base_keys.append('Money')
         except ImportError:
             Money = None
 
         if Money is not None:
             base_keys.append('Money')
 
+        if dateutil is not None:
+            base_keys.append('dateutil')
+
+        try:
+            import pycel
+        except ImportError:
+            pycel = None
+
+        if pycel is not None:
+            try:
+                from inspect import getmembers
+                xl_members = getmembers(pycel.excellib)
+                xl_members += getmembers(pycel.lib.date_time)
+                xl_members += getmembers(pycel.lib.engineering)
+                xl_members += getmembers(pycel.lib.information)
+                xl_members += getmembers(pycel.lib.logical)
+                xl_members += getmembers(pycel.lib.lookup)
+                xl_members += getmembers(pycel.lib.stats)
+                xl_members += getmembers(pycel.lib.text)
+                XL_LIST = [n for n, _ in xl_members]
+
+                for name, fun in xl_members:
+                    globals()[name] = fun
+                    base_keys += XL_LIST
+
+            except UnboundLocalError:
+                pass  # openpyxl is not installed
+
         for key in list(globals().keys()):
             if key not in base_keys:
                 globals().pop(key)
