@@ -31,10 +31,10 @@ from io import StringIO
 from sys import exc_info
 from traceback import print_exception
 
-from PyQt5.QtCore import Qt
-from PyQt5.QtGui import QColor
-from PyQt5.QtWidgets import QDialog, QVBoxLayout, QDialogButtonBox, QSplitter
-from PyQt5.QtWidgets import QTextEdit
+from PyQt6.QtCore import Qt
+from PyQt6.QtGui import QColor
+from PyQt6.QtWidgets import QDialog, QVBoxLayout, QDialogButtonBox, QSplitter
+from PyQt6.QtWidgets import QTextEdit
 
 try:
     from pyspread.lib.spelltextedit import SpellTextEdit
@@ -72,12 +72,13 @@ class MacroPanel(QDialog):
         self.result_viewer = QTextEdit(self)
         self.result_viewer.setReadOnly(True)
 
-        self.splitter = QSplitter(Qt.Vertical, self)
+        self.splitter = QSplitter(Qt.Orientation.Vertical, self)
 
         self.splitter.addWidget(self.macro_editor)
         self.splitter.addWidget(self.result_viewer)
 
-        self.button_box = QDialogButtonBox(QDialogButtonBox.Apply)
+        self.button_box = QDialogButtonBox(
+            QDialogButtonBox.StandardButton.Apply)
 
     def _layout(self):
         """Layout dialog widgets"""
