@@ -31,6 +31,7 @@ from contextlib import contextmanager
 from copy import copy
 import csv
 import io
+import logging
 import numpy
 import os.path
 from pathlib import Path
@@ -38,13 +39,13 @@ from shutil import move
 from tempfile import NamedTemporaryFile
 from typing import Iterable, Tuple
 
-from PyQt5.QtCore import (Qt, QMimeData, QModelIndex, QBuffer, QRect, QRectF,
+from PyQt6.QtCore import (Qt, QMimeData, QModelIndex, QBuffer, QRect, QRectF,
                           QItemSelectionModel, QSize)
-from PyQt5.QtGui import QTextDocument, QImage, QPainter
-from PyQt5.QtWidgets import (QApplication, QMessageBox, QInputDialog,
-                             QStyleOptionViewItem, QTableView, QUndoCommand)
+from PyQt6.QtGui import QTextDocument, QImage, QPainter, QUndoCommand
+from PyQt6.QtWidgets import (QApplication, QMessageBox, QInputDialog,
+                             QStyleOptionViewItem, QTableView)
 try:
-    from PyQt5.QtSvg import QSvgGenerator
+    from PyQt6.QtSvg import QSvgGenerator
 except ImportError:
     QSvgGenerator = None
 
@@ -55,6 +56,11 @@ except ImportError:
     matplotlib = None
     matplotlib_figure = None
 
+try:
+    import openpyxl
+except ImportError:
+    openpyxl = None
+
 try:
     from pyspread import commands
     from pyspread.dialogs \
@@ -64,6 +70,7 @@ try:
                 CsvImportDialog, CsvExportDialog, CsvExportAreaDialog,
                 FileExportDialog, SvgExportAreaDialog, SinglePageArea)
     from pyspread.interfaces.pys import PysReader, PysWriter
+    from pyspread.interfaces.xlsx import XlsxReader
     from pyspread.lib.attrdict import AttrDict
     from pyspread.lib.hashing import sign, verify
     from pyspread.lib.selection import Selection
@@ -71,7 +78,7 @@ try:
     from pyspread.lib.csv import csv_reader, convert
     from pyspread.lib.file_helpers import \
         (linecount, file_progress_gen, ProgressDialogCanceled)
-    from pyspread.model.model import CellAttribute
+    from pyspread.model.model import CellAttribute, class_format_functions
 except ImportError:
     import commands
     from dialogs \
@@ -81,6 +88,7 @@ except ImportError:
                 CsvImportDialog, CsvExportDialog, CsvExportAreaDialog,
                 FileExportDialog, SvgExportAreaDialog, SinglePageArea)
     from interfaces.pys import PysReader, PysWriter
+    from interfaces.xlsx import XlsxReader
     from lib.attrdict import AttrDict
     from lib.hashing import sign, verify
     from lib.selection import Selection
@@ -88,7 +96,7 @@ except ImportError:
     from lib.csv import csv_reader, convert
     from lib.file_helpers import \
         (linecount, file_progress_gen, ProgressDialogCanceled)
-    from model.model import CellAttribute
+    from model.model import CellAttribute, class_format_functions
 
 
 class Workflows:
@@ -103,7 +111,7 @@ class Workflows:
     def busy_cursor(self):
         """:class:`~contextlib.contextmanager` that displays a busy cursor"""
 
-        QApplication.setOverrideCursor(Qt.WaitCursor)
+        QApplication.setOverrideCursor(Qt.CursorShape.WaitCursor)
         yield
         QApplication.restoreOverrideCursor()
 
@@ -286,11 +294,25 @@ class Workflows:
         except OSError:
             self.main_window.safe_mode = True
 
-        # File compression handling
+        # File format handling
         if filepath.suffix == ".pysu":
             fopen = open
-        else:
+            freader = PysReader
+        elif filepath.suffix == ".pys":
             fopen = bz2.open
+            freader = PysReader
+        elif filepath.suffix == ".xlsx":
+            if openpyxl is None:
+                msg = f"openpyxl is not installed. {filepath} not opened."
+                self.main_window.statusBar().showMessage(msg)
+                return
+            fopen = open
+            freader = XlsxReader
+        else:
+            msg = f"Unknown file format {filepath.suffix}. "\
+                  f"{filepath} not opened."
+            self.main_window.statusBar().showMessage(msg)
+            return
 
         # Process events before showing the modal progress dialog
         QApplication.instance().processEvents()
@@ -304,18 +326,20 @@ class Workflows:
 
         try:
             with fopen(filepath, "rb") as infile:
-                reader = PysReader(infile, code_array)
+                reader = freader(infile, code_array)
                 try:
                     for i, _ in file_progress_gen(self.main_window, reader,
                                                   title, label, filelines):
                         pass
                 except Exception as error:
+                    logging.error(error)
                     grid.model.reset()
                     self.main_window.statusBar().showMessage(str(error))
                     self.main_window.safe_mode = False
                     return
                 except ProgressDialogCanceled:
                     msg = f"File open stopped by user at line {i}."
+                    logging.info(msg)
                     self.main_window.statusBar().showMessage(msg)
                     grid.model.reset()
                     self.main_window.safe_mode = False
@@ -344,6 +368,8 @@ class Workflows:
             # Update index widgets
             grid.update_index_widgets()
 
+            grid.model.dataChanged.emit(QModelIndex(), QModelIndex())
+
             # Select upper left cell because initial selection oddities
             grid.reset_selection()
 
@@ -605,11 +631,13 @@ class Workflows:
                                        rows-row, columns-column)
 
             title = "CSV Content Exceeds Grid Shape"
-            choices = QMessageBox.No | QMessageBox.Yes | QMessageBox.Cancel
-            default_choice = QMessageBox.No
+            choices = QMessageBox.StandardButton.No \
+                | QMessageBox.StandardButton.Yes \
+                | QMessageBox.StandardButton.Cancel
+            default_choice = QMessageBox.StandardButton.No
             choice = QMessageBox.question(self.main_window, title, text,
                                           choices, default_choice)
-            if choice == QMessageBox.Yes:
+            if choice == QMessageBox.StandardButton.Yes:
                 # Resize grid
                 target_rows = min(max_rows, max(csv_rows + row, rows))
                 target_columns = min(max_columns,
@@ -618,7 +646,7 @@ class Workflows:
                 rows = target_rows
                 columns = target_columns
 
-            elif choice == QMessageBox.Cancel:
+            elif choice == QMessageBox.StandardButton.Cancel:
                 return
 
         # Now fill the grid
@@ -1106,7 +1134,8 @@ class Workflows:
         renderer = grid.model.code_array.cell_attributes[current].renderer
 
         if renderer == "text":
-            clipboard.setText(str(data))
+            clipboard.setText(grid.model.data(grid.currentIndex()))
+            # clipboard.setText(str(data))
 
         elif renderer == "image":
             if isinstance(data, QImage):
@@ -1156,10 +1185,17 @@ class Workflows:
 
         def str_nn(ele):
             """str which returns '' if ele is None"""
-
             if ele is None:
                 return ''
-            return str(ele)
+
+            try:
+                if ele.__class__ in class_format_functions:
+                    format_function = class_format_functions[ele.__class__]
+                    return format_function(ele)
+
+                return str(ele)
+            except Exception as err:
+                return str(err)
 
         table = grid.table
         selection = grid.selection
@@ -1385,7 +1421,7 @@ class Workflows:
             # Bitmap Image
             image = clipboard.image()
             buffer = QBuffer()
-            buffer.open(QBuffer.ReadWrite)
+            buffer.open(QBuffer.OpenModeFlag.ReadWrite)
             image.save(buffer, "PNG")
             buffer.seek(0)
             image_data = buffer.readAll()
@@ -1894,7 +1930,8 @@ class Workflows:
 
         index = grid.currentIndex()
         grid.clearSelection()
-        grid.selectionModel().select(index, QItemSelectionModel.Select)
+        grid.selectionModel().select(index,
+                                     QItemSelectionModel.SelectionFlag.Select)
 
         if filepath.suffix == ".svg":
             svg = self._read_svg_str(filepath, encoding='utf-8')
@@ -1936,12 +1973,13 @@ class Workflows:
         if code is not None:
             chart_dialog.editor.setPlainText(code)
 
-        if chart_dialog.exec_() == ChartDialog.Accepted:
+        if chart_dialog.exec() == ChartDialog.DialogCode.Accepted:
             code = chart_dialog.editor.toPlainText()
             grid.current = current
             index = grid.currentIndex()
             grid.clearSelection()
-            grid.selectionModel().select(index, QItemSelectionModel.Select)
+            grid.selectionModel().select(
+                index, QItemSelectionModel.SelectionFlag.Select)
             grid.on_matplotlib_renderer_pressed()
 
             description = f"Insert chart into cell {index}"
